import type { IamRoleInlinePolicy } from "@cdktf/provider-aws/lib/iam-role";
import { IamRole } from "@cdktf/provider-aws/lib/iam-role";
import { Construct } from "constructs";
/**
 * Interface for an OpenID Connect (OIDC) provider that GitHub Actions can use.
 */
export interface IOpenIdConnectProvider {
    /**
     * The Amazon Resource Name (ARN) of the OIDC provider.
     */
    readonly providerArn: string;
}
/**
 * Properties for configuring the GitHub Actions OpenID Connect provider.
 */
export interface GitHubActionsOpenIdConnectProviderProps {
    /**
     * Optional thumbprints to verify GitHub's certificates.
     * Default is the predefined thumbprints.
     */
    readonly thumbprints?: string[];
}
/**
 * Represents an OpenID Connect (OIDC) provider for GitHub Actions.
 *
 * This construct creates an IAM OIDC provider that allows GitHub Actions
 * to assume roles using web identity federation.
 */
export declare class GitHubActionsOpenIdConnectProvider extends Construct implements IOpenIdConnectProvider {
    /**
     * The Amazon Resource Name (ARN) of the created OpenID Connect provider.
     */
    readonly providerArn: string;
    /**
     * Constructs a new instance of `GitHubActionsOpenIdConnectProvider`.
     *
     * @param scope - The construct scope to define the provider within.
     * @param id - The unique identifier for this provider.
     * @param props - Optional properties for the OIDC provider.
     */
    constructor(scope: Construct, id: string, props?: GitHubActionsOpenIdConnectProviderProps);
    /**
     * Imports an existing GitHub Actions OpenID Connect provider by ARN.
     *
     * @param scope - The construct scope to define the provider within.
     * @returns An object that implements `IOpenIdConnectProvider`.
     */
    static fromGitHubActionsOpenIdConnectProvider(scope: Construct): IOpenIdConnectProvider;
}
/**
 * Properties for creating a GitHub Actions IAM role.
 */
export interface GitHubActionsRoleProps {
    /**
     * The name for the GitHub Actions IAM role.
     *
     * @default - "GitHubActionsRole"
     */
    readonly roleName?: string;
    /**
     * The OpenID Connect provider that GitHub Actions will use to assume this role.
     */
    readonly provider: IOpenIdConnectProvider;
    /**
     * A list of GitHub repositories that are permitted to assume this role.
     *
     * Each repository should be formatted as `owner/repo`.
     */
    readonly repos?: string[];
    /**
     * Additional custom subject claims to allow for the role.
     *
     * Each claim should conform to the format used in GitHub OIDC conditions.
     */
    readonly subjectClaims?: string[];
    /**
     * Inline policies that define the permissions for the IAM role.
     * This allows configuring the role with specific policies.
     */
    readonly inlinePolicy?: IamRoleInlinePolicy[];
}
/**
 * Creates an IAM Role for GitHub Actions workflows using an OpenID Connect provider.
 *
 * The role includes policies allowing the assumption of bootstrap roles and access to ECR authorization.
 */
export declare class GitHubActionsRole extends IamRole {
    /**
     * Constructs a new instance of `GitHubActionsRole`.
     *
     * @param scope - The construct scope to define the role within.
     * @param id - The unique identifier for this role.
     * @param props - The properties for configuring the GitHub Actions role.
     */
    constructor(scope: Construct, id: string, props: GitHubActionsRoleProps);
}
